@@ -4,9 +4,9 @@ use Shell::Cmd;
 $obj = new Shell::Cmd;
 $obj->options("echo" => "echo");
 $obj->options("mode" => "run");
-$obj->cmd("if [ -d /tmp ]; then",  { "flow" => 1 },
-          "   ls /tmp",
-          "fi",                    { "flow" => 1 },
+$obj->cmd("if [ -d /tmp ]; then",
+          "ls /tmp",
+          "fi",
          );
 ($err) = $obj->run();
 
